/**
 * Mobile navigation
 *
 * @package    Icelander
 * @copyright  WebMan Design, Oliver Juhas
 *
 * @since    1.0.0
 * @version  1.6.0
 */

( function( $ ) {
	'use strict';

	var
		$siteNavigation   = $( document.getElementById( 'site-navigation' ) ),
		$menuToggleButton = $( '#menu-toggle, #menu-toggle-bar' ),
		$breakpoints      = ( 'undefined' !== typeof $icelanderBreakpoints ) ? ( $icelanderBreakpoints ) : ( { 'l' : 880 } );

	function mobileMenuActions() {

		// Processing

			if ( ! $siteNavigation.hasClass( 'is-active' ) ) {
				$menuToggleButton
					.attr( 'aria-expanded', 'false' );
			}

			$siteNavigation
				.on( 'keydown', function( e ) {
					if ( e.which === 27 ) {

						// ESC key
						e.preventDefault();

						$siteNavigation
							.removeClass( 'is-active' );

						$menuToggleButton
							.attr( 'aria-expanded', 'false' );

						$menuToggleButton
							.focus();
					}
				} );

	} // /mobileMenuActions

	if ( parseInt( $breakpoints['l'] ) >= window.innerWidth ) {

		$siteNavigation
			.removeClass( 'is-active' );

		mobileMenuActions();
	}

	$menuToggleButton
		.on( 'click', function( e ) {

			e.preventDefault();

			$siteNavigation
				.toggleClass( 'is-active' );

			if ( $siteNavigation.hasClass( 'is-active' ) ) {
				$menuToggleButton
					.attr( 'aria-expanded', 'true' );
			} else {
				$menuToggleButton
					.attr( 'aria-expanded', 'false' );
			}
		} );

	/**
	 * Refocus to menu toggle button once the end of the menu is reached
	 */
	$siteNavigation
		.on( 'focus.aria', '.menu-toggle-skip-link', function( e ) {

			$menuToggleButton
				.focus();
		} );

	/**
	 * Disable mobile navigation on wider screens
	 */
	$( window )
		.on( 'resize orientationchange', function( e ) {
			if ( parseInt( $breakpoints['l'] ) < window.innerWidth ) {

				// On desktops
				$siteNavigation
					.removeClass( 'is-active' );

				$menuToggleButton
					.attr( 'aria-expanded', 'true' );

			} else {

				// On mobiles
				mobileMenuActions();
			}
		} );

} )( jQuery );
