<?php
/**
 * WebMan WordPress Theme Framework
 *
 * Theme options with `__` prefix (`get_theme_mod( '__option_id' )`) are theme
 * setup related options and can not be edited via customizer.
 * This way we prevent creating additional options in the database.
 *
 * @copyright  WebMan Design, Oliver Juhas
 * @license    GPL-3.0, http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @link  https://github.com/webmandesign/webman-theme-framework
 * @link  http://www.webmandesign.eu
 *
 * @package     WebMan WordPress Theme Framework
 * @subpackage  Core
 *
 * @version  2.5.6
 * @version  1.4.0
 *
 * Used global hooks:
 *
 * @uses  wmhook_icelander_theme_options
 *
 * Used development prefixes:
 *
 * @uses theme_slug
 * @uses text_domain
 * @uses prefix_var
 * @uses prefix_hook
 * @uses theme_name
 * @uses prefix_class
 * @uses prefix_constant
 *
 * Contents:
 *
 * 10) Constants
 * 20) Load
 */





/**
 * 10) Constants
 */

	// Theme version

		if ( ! defined( 'ICELANDER_THEME_VERSION' ) ) {
			define( 'ICELANDER_THEME_VERSION', wp_get_theme( 'icelander' )->get( 'Version' ) );
		}

	// Paths

		if ( ! defined( 'ICELANDER_PATH' ) ) {
			define( 'ICELANDER_PATH', trailingslashit( get_template_directory() ) );
		}

		if ( ! defined( 'ICELANDER_LIBRARY_DIR' ) ) {
			define( 'ICELANDER_LIBRARY_DIR', trailingslashit( basename( dirname( __FILE__ ) ) ) );
		}

		define( 'ICELANDER_LIBRARY', trailingslashit( ICELANDER_PATH . ICELANDER_LIBRARY_DIR ) );





/**
 * 20) Load
 */

	// Core class

		require ICELANDER_LIBRARY . 'includes/classes/class-core.php';

	// Customize (has to be frontend accessible, otherwise it hides the theme settings)

		// Sanitize class

			require ICELANDER_LIBRARY . 'includes/classes/class-sanitize.php';

		// Customize class

			require ICELANDER_LIBRARY . 'includes/classes/class-customize.php';

		// CSS variables generator class

			require ICELANDER_LIBRARY . 'includes/classes/class-css-variables.php';

	// Admin

		if ( is_admin() ) {

			// Load optional theme welcome page

				$welcome_page = get_theme_file_path( 'includes/welcome/welcome.php' );
				if ( file_exists( $welcome_page ) ) {
					require ICELANDER_LIBRARY . 'includes/classes/class-admin.php';
					require $welcome_page;
				}

			// Optional plugins suggestions

				$plugins_suggestions = get_theme_file_path( 'includes/tgmpa/plugins.php' );
				if ( (bool) apply_filters( 'wmhook_icelander_plugins_suggestion_enabled', file_exists( $plugins_suggestions ) ) ) {
					require ICELANDER_LIBRARY . 'includes/vendor/tgmpa/class-tgm-plugin-activation.php';
					require $plugins_suggestions;
				}

			// Optional child theme generator

				if ( apply_filters( 'wmhook_icelander_child_theme_generator_enabled', false ) ) {
					require ICELANDER_LIBRARY . 'includes/vendor/use-child-theme/class-use-child-theme.php';
				}

		}
